Struct BatchError

pub struct BatchError<T> { /* private fields */ }
An error encountered processing a batch.

The error may contain part of the batch to retry.

Implementations

Source

impl<T> BatchError<T>

pub fn no_retry(_: impl Error + Send + Sync + 'static) -> Self

An error that can’t be retried.

pub fn retry(_: impl Error + Send + Sync + 'static, retryable: T) -> Self

An error that can be retried.

pub fn try_into_retryable(self) -> Result<T, BatchError<T>>

Try convert the error into a retryable value.

pub fn into_retryable(self) -> Option<T>

Try get the retryable batch from the error.

If the error is not retryable then this method will return None.

pub fn map_retryable<U>( self, f: impl FnOnce(Option<T>) -> Option<U>, ) -> BatchError<U>

Map the retryable batch.

If the batch is already retryable, the input to f will be Some. The resulting batch is retryable if f returns Some.